@@ -136,7 +136,7 @@ class MyWhatify:
                 ret_list = cls.get_prediction_list(search_term=data_name)
                 if len(ret_list) > 0:
                     for pred_check in ret_list:
-                        if pred_check['ensemble_id'] == ensemble_id:
+                        if pred_check['ensemble_id'] == ensemble_id and pred_check['datasource_name'] == data_name:
                             return int(ret_list[0]['id']), True, None
             try:
                 if not (file_path or data_id):
